Command line interface — arginfer 0.1.dev80+gf4bcddf.d20210325 documentation

# Command line interface

`arginfer` provides a Command Line Interface to access the Python API.

    $ arginfer

or

    $ python3 -m arginfer

The second command is useful when multiple versions of Python are installed or if the arginfer executable is not installed on your path.

## Argument details

This is the command line interface for arginfer, a probabilistic method to infer the Ancestral Recombination Graph.

    usage: arginfer [-h] [-V] {infer} ...

### Positional Arguments

`subcommand`

  Possible choices: infer

### Named Arguments

`-V, --version`

  show program's version number and exit

### Sub-commands:

#### infer

Takes the data or the ARG in tree sequence full_ARG format and returns MCMC sampled ARGs.

    arginfer infer [-h] [--tsfull TSFULL] [--input_path INPUT_PATH]
                   [--haplotype_name HAPLOTYPE_NAME]
                   [--ancAllele_name ANCALLELE_NAME] [--snpPos_name SNPPOS_NAME]
                   [--iteration ITERATION] [--thin THIN] [--burn BURN]
                   [--sample_size SAMPLE_SIZE] [--seq_length SEQ_LENGTH] [--Ne NE]
                   [--recombination_rate RECOMBINATION_RATE]
                   [--mutation_rate MUTATION_RATE] [--outpath OUTPATH] [-p]
                   [--random-seed RANDOM_SEED] [-v] [--verify]

##### Named Arguments

`--tsfull`

  an msprime .args file. If None, build an ARG from haplotype data

`--input_path`

  The path to input data, this is the path to haplotype, ancestral allele, and snp_pos

`--haplotype_name`

  the haplotype file name

`--ancAllele_name`

  a txt file of ancestral allele for each snp

`--snpPos_name`

  a txt file of SNP chrom position

`--iteration, -I`

  the number of mcmc iterations

`--thin`

  > thining steps

`--burn, -b`

  > The burn-in

`--sample_size, -n`

  > sample size

`--seq_length, -L`

  sequence length

`--Ne`

  > effective population size

`--recombination_rate, -r`

  > the recombination rate per site per generation

`--mutation_rate, -mu`

  the mutation rate per site per generation

`--outpath, -O`

  The output path

`-p, --plot`

  plot the output

`--random-seed, -s`
`-v, --verbose`

  increase output verbosity

`--verify`

  verify the output ARG